@@ -1,4 +1,4 @@
-from ...requests import media_res_url
+from ...urls import media_res_url
 from ...l10n import lazy_gettext
 
 
